from typing import List, Optional

from orchestrator.domain.base import ProductBlockModel
from orchestrator.types import SubscriptionLifecycle

from geant_service_orchestrator.products.product_blocks.trunk_config \
    import TrunkConfigBlock, TrunkConfigBlockInactive,\
    TrunkConfigBlockProvisioning


class TrunkConfigSideBlockInactive(
        ProductBlockModel,
        lifecycle=[SubscriptionLifecycle.INITIAL],
        product_block_name="TrunkConfigSideBlock"):
    trunk_config: TrunkConfigBlockInactive
    trunk_config_side_id: Optional[int] = None
    fqdn: Optional[str] = None
    ae_name: Optional[str] = None
    geant_a_sid: Optional[str] = None
    ipv4_address: Optional[str] = None
    ipv6_address: Optional[str] = None
    members: Optional[List[str]] = None


class TrunkConfigSideBlockProvisioning(
        TrunkConfigSideBlockInactive,
        lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    trunk_config: TrunkConfigBlockProvisioning
    trunk_config_side_id: Optional[int] = None
    fqdn: str
    ae_name: str
    geant_a_sid: str
    ipv4_address: Optional[str] = "127.0.0.1"
    ipv6_address: Optional[str] = "::1"
    members: List[str]


class TrunkConfigSideBlock(
        TrunkConfigSideBlockProvisioning,
        lifecycle=[SubscriptionLifecycle.ACTIVE]):
    trunk_config: TrunkConfigBlock
    trunk_config_side_id: int
    fqdn: str
    ae_name: str
    geant_a_sid: str
    ipv4_address: str
    ipv6_address: str
    members: List[str]
